Changelog
---------

0.1.6 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Sets the initial user as the default reply to address.
  [href]

0.1.5 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Fixes wrong login link in welcome e-mail.
  [href]

0.1.4 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Uses the latest onegov.core and onegov.town release.
  [href]

0.1.3 (2016-01-27)
~~~~~~~~~~~~~~~~~~~

- Prevents double clicks on submit buttons.
  [href]

- Adds a welcome e-mail.
  [href]

0.1.2 (2016-01-25)
~~~~~~~~~~~~~~~~~~~

- Use latest onegov.town release.
  [href]

0.1.1 (2016-01-23)
~~~~~~~~~~~~~~~~~~~

- Includes the requirements.txt build artifact on the Github Releases page.
  [href]

0.1.0 (2016-01-22)
~~~~~~~~~~~~~~~~~~~

- Initial Release
  [href]